# Change Log
All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/).

## [0.1.0] - Web interface
### Added
- Web interface
- Command line application
- RESTful API

[0.1.0]: https://bitbucket.org/bkvaluemeal/d3cryp7.py/issues/1/web-interface
